@@ -42,13 +42,18 @@ G_BEGIN_DECLS
 {
   GnlObject parent;
 
-  guint num_sinks;	/* Number of sink inputs. */
+  gint num_sinks;               /* Number of sink inputs. */
 
   /* <private> */
-  guint realsinks;	/* Number of real sink pads. */
-  GList *sinks;		/* Sinkpads */
+  gboolean dynamicsinks;        /* TRUE if element has request pads */
+  gint realsinks;               /* Number of real sink pads. */
 
-  GstElement *element;
+  /* FIXME : We might need to use a lock to access this list */
+  GList * sinks;		/* The sink ghostpads */
+  
+  GstPad *ghostpad;		/* src ghostpad */
+
+  GstElement *element;		/* controlled element */
 };
 
 struct _GnlOperationClass
