@@ -1,180 +1,4 @@
-
-#include <gst/check/gstcheck.h>
-
-typedef struct _Segment {
-  gdouble	rate;
-  GstFormat	format;
-  gint64	start, stop, position;
-}	Segment;
-
-typedef struct _CollectStructure {
-  GstElement	*comp;
-  GstElement	*sink;
-  guint64	last_time;
-  gboolean	gotsegment;
-  GList		*expected_segments;
-}	CollectStructure;
-
-static GstElement *
-gst_element_factory_make_or_warn (const gchar * factoryname, const gchar * name)
-{
-  GstElement * element;
-
-  element = gst_element_factory_make (factoryname, name);
-  fail_unless (element != NULL, "Failed to make element %s", factoryname);
-  return element;
-}
-
-static void
-composition_pad_added_cb (GstElement *composition, GstPad *pad, CollectStructure * collect)
-{
-  fail_if (!(gst_element_link (composition, collect->sink)));
-}
-
-/* return TRUE to discard the Segment */
-static gboolean
-compare_segments (Segment * segment, GstEvent * event)
-{
-  gboolean update;
-  gdouble rate;
-  GstFormat format;
-  gint64 start, stop, position;
-
-  gst_event_parse_new_segment (event, &update, &rate, &format, &start, &stop, &position);
-
-  GST_DEBUG ("Got NewSegment update:%d, rate:%f, format:%d, start:%"GST_TIME_FORMAT
-	     ", stop:%"GST_TIME_FORMAT", position:%"GST_TIME_FORMAT,
-	     update, rate, format, GST_TIME_ARGS (start),
-	     GST_TIME_ARGS (stop),
-	     GST_TIME_ARGS (position));
-
-  GST_DEBUG ("Expecting rate:%f, format:%d, start:%"GST_TIME_FORMAT
-	     ", stop:%"GST_TIME_FORMAT", position:%"GST_TIME_FORMAT,
-	     segment->rate, segment->format,
-	     GST_TIME_ARGS (segment->start),
-	     GST_TIME_ARGS (segment->stop),
-	     GST_TIME_ARGS (segment->position));
-
-  if (update) {
-    GST_DEBUG ("was update, ignoring");
-    return FALSE;
-  }
-  fail_if (rate != segment->rate);
-  fail_if (format != segment->format);
-  fail_if (start != segment->start);
-  fail_if (stop != segment->stop);
-  fail_if (position != segment->position);
-
-  GST_DEBUG ("Segment was valid, discarding expected Segment");
-
-  return TRUE;
-}
-
-static gboolean
-sinkpad_event_probe (GstPad * sinkpad, GstEvent * event, CollectStructure * collect)
-{
-  Segment * segment;
-  
-  if (GST_EVENT_TYPE (event) == GST_EVENT_NEWSEGMENT) {
-    fail_if (collect->expected_segments == NULL);
-    segment = (Segment *) collect->expected_segments->data;
-
-    if (compare_segments (segment, event)) {
-      collect->expected_segments = g_list_remove (collect->expected_segments, segment);
-      g_free (segment);
-    }
-    collect->gotsegment = TRUE;
-  }
-
-  return TRUE;
-}
-
-static gboolean
-sinkpad_buffer_probe (GstPad * sinkpad, GstBuffer * buffer, CollectStructure * collect)
-{
-  fail_if(!collect->gotsegment);
-  return TRUE;
-}
-
-static GstElement *
-videotest_gnl_src (const gchar * name, guint64 start, gint64 duration, gint pattern, guint priority)
-{
-  GstElement * gnlsource = NULL;
-  GstElement * videotestsrc = NULL;
-
-  videotestsrc = gst_element_factory_make_or_warn ("videotestsrc", NULL);
-  g_object_set (G_OBJECT (videotestsrc), "pattern", pattern, NULL);
-
-  gnlsource = gst_element_factory_make_or_warn ("gnlsource", name);
-  fail_if (gnlsource == NULL);
-
-  g_object_set (G_OBJECT (gnlsource),
-		"start", start,
-		"duration", duration,
-		"media-start", start,
-		"media-duration", duration,
-		"priority", priority,
-		NULL);
-
-  gst_bin_add (GST_BIN (gnlsource), videotestsrc);
-  
-  return gnlsource;
-}
-
-static GstElement *
-videotest_in_bin_gnl_src (const gchar * name, guint64 start, gint64 duration, gint pattern, guint priority)
-{
-  GstElement * gnlsource = NULL;
-  GstElement * videotestsrc = NULL;
-  GstElement * bin = NULL;
-
-  videotestsrc = gst_element_factory_make_or_warn ("videotestsrc", NULL);
-  g_object_set (G_OBJECT (videotestsrc), "pattern", pattern, NULL);
-  bin = gst_bin_new (NULL);
-
-  gnlsource = gst_element_factory_make_or_warn ("gnlsource", name);
-  fail_if (gnlsource == NULL);
-
-  g_object_set (G_OBJECT (gnlsource),
-		"start", start,
-		"duration", duration,
-		"media-start", start,
-		"media-duration", duration,
-		"priority", priority,
-		NULL);
-
-  gst_bin_add (GST_BIN (bin), videotestsrc);
-
-  gst_bin_add (GST_BIN (gnlsource), bin);
-  
-  gst_element_add_pad (bin, gst_ghost_pad_new ("src", gst_element_get_pad (videotestsrc, "src")));
-
-  return gnlsource;
-}
-
-static Segment *
-segment_new (gdouble rate, GstFormat format, gint64 start, gint64 stop, gint64 position)
-{
-  Segment * segment;
-
-  segment = g_new0 (Segment, 1);
-
-  segment->rate = rate;
-  segment->format = format;
-  segment->start = start;
-  segment->stop = stop;
-  segment->position = position;
-
-  return segment;
-}
-
-#define check_start_stop_duration(object, startval, stopval, durval)	\
-  { \
-    g_object_get (object, "start", &start, "stop", &stop, "duration", &duration, NULL); \
-    fail_if (start != startval); \
-    fail_if (stop != stopval); \
-    fail_if (duration != durval); \
-  }
+#include "common.h"
 
 
 GST_START_TEST (test_time_duration)
@@ -421,9 +245,10 @@ GST_START_TEST (test_one_after_other)
 
   fail_if (collect->expected_segments != NULL);
 
+  gst_object_unref (GST_OBJECT(sinkpad));
+
   fail_if (gst_element_set_state (GST_ELEMENT (pipeline), GST_STATE_NULL) == GST_STATE_CHANGE_FAILURE);
 
-  gst_object_unref (GST_OBJECT(sinkpad));
   ASSERT_OBJECT_REFCOUNT_BETWEEN(pipeline, "main pipeline", 1, 2);
   gst_object_unref (pipeline);
   ASSERT_OBJECT_REFCOUNT_BETWEEN(bus, "main bus", 1, 2);
@@ -732,11 +557,12 @@ GST_START_TEST (test_one_bin_after_other)
     }
   }
 
+  gst_object_unref (GST_OBJECT (sinkpad));
+
   fail_if (collect->expected_segments != NULL);
 
   fail_if (gst_element_set_state (GST_ELEMENT (pipeline), GST_STATE_NULL) == GST_STATE_CHANGE_FAILURE);
 
-  gst_object_unref (GST_OBJECT (sinkpad));
   ASSERT_OBJECT_REFCOUNT_BETWEEN(pipeline, "main pipeline", 1, 2);
   gst_object_unref (pipeline);
   ASSERT_OBJECT_REFCOUNT_BETWEEN(bus, "main bus", 1, 2);
